# scs_analysis
_Information management and analysis utilities for South Coast Science data consumers_

Detailed information at the [scs_analysis wiki](https://github.com/south-coast-science/scs_analysis/wiki).
#
**Installation:**

The package can be installed either by git clone, or as a [pypi project](https://pypi.org/project/scs-analysis/):

```
pip install scs-analysis
```

- Windows 10 users may need to install the PyCurl executable for the PIP installer to run
which can be found here: 
https://dl.bintray.com/pycurl/pycurl/ 
- Linux users may need to install an open SSL library for the PIP installer to run

```
sudo apt install libcurl4-openssl-dev libssl-dev
```

https://uoa-eresearch.github.io/eresearch-cookbook/recipe/2014/11/26/python-virtual-env/
